Module: GetText::RGetText

Extended by:
GetText
Defined in:
lib/gettext/tools/rgettext.rb

Overview

:nodoc:

Constant Summary collapse

VERSION =

constant values

GetText::VERSION
DATE =
%w($Date: 2008/08/06 17:35:52 $)[1]
MAX_LINE_LEN =
70

Constants included from GetText

BOM_UTF8

Class Method Summary collapse

Methods included from GetText

N_, Nn_, bindtextdomain, bindtextdomain_to, cgi, cgi=, create_mofiles, create_mofiles_org, gettext, included, locale, msgmerge, ngettext, npgettext, nsgettext, output_charset, pgettext, remove_bom, rgettext, rmsgfmt, rmsgmerge, set_cgi, set_current_locale, set_locale, set_output_charset, sgettext, textdomain, textdomain_to, update_pofiles, update_pofiles_org

Class Method Details

.add_parser(klass) ⇒ Object

Add an option parser the option parser module requires to have target?(file) and parser(file, ary) method.

require 'gettext/rgettext'
module FooParser
  module_function
  def target?(file)
    File.extname(file) == '.foo'  # *.foo file only.
  end
  def parse(file, ary)
    :
    return ary # [["msgid1", "foo.rb:200"], ["msgid2", "bar.rb:300", "baz.rb:400"], ...]
  end
end

GetText::RGetText.add_parser(FooParser)


66
67
68
# File 'lib/gettext/tools/rgettext.rb', line 66

def add_parser(klass)
  @ex_parsers.insert(0, klass)
end

.check_optionsObject

:nodoc:



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/gettext/tools/rgettext.rb', line 151

def check_options # :nodoc:
  output = STDOUT

  opts = OptionParser.new
  opts.banner = _("Usage: %s input.rb [-r parser.rb] [-o output.pot]") % $0
  opts.separator("")
  opts.separator(_("Extract translatable strings from given input files."))
  opts.separator("")
  opts.separator(_("Specific options:"))

  opts.on("-o", "--output=FILE", _("write output to specified file")) do |out|
    unless FileTest.exist? out
      output = File.new(File.expand_path(out), "w+")
    else
      $stderr.puts(_("File '%s' already exists.") % out)
      exit 1
    end
  end

  opts.on("-r", "--require=library", _("require the library before executing rgettext")) do |out|
    require out
  end

  opts.on("-d", "--debug", _("run in debugging mode")) do
    $DEBUG = true
  end

  opts.on_tail("--version", _("display version information and exit")) do
    puts "#{$0} #{VERSION} (#{DATE})"
    puts "#{File.join(Config::CONFIG["bindir"], Config::CONFIG["RUBY_INSTALL_NAME"])} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) [#{RUBY_PLATFORM}]"
    exit
  end

  opts.parse!(ARGV)

  if ARGV.size == 0
    puts opts.help
    exit 1
  end

  [ARGV, output]
end

.generate_pot(ary) ⇒ Object

:nodoc:



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/gettext/tools/rgettext.rb', line 97

def generate_pot(ary) # :nodoc:
  str = ""
  ary.each do |target|
    # extracted comments
    if target.extracted_comment
      target.extracted_comment.split("\n").each do |comment_line|
        str << "\n#. #{comment_line.strip}"
      end
    end

    # references
    curr_pos = MAX_LINE_LEN
    target.occurrences.each do |e|
      if curr_pos + e.size > MAX_LINE_LEN
        str << "\n#:"
        curr_pos = 3
      else
        curr_pos += (e.size + 1)
      end
      str << " " << e
    end

    # msgctxt, msgid, msgstr
    str << "\nmsgctxt \"" << target.msgctxt << "\"" if target.msgctxt
    str << "\nmsgid \"" << target.escaped(:msgid) << "\"\n"
    if target.plural
      str << "msgid_plural \"" << target.escaped(:plural) << "\"\n"
      str << "msgstr[0] \"\"\n"
      str << "msgstr[1] \"\"\n"
    else
      str << "msgstr \"\"\n"
    end
  end
  str
end

.generate_pot_headerObject

:nodoc:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/gettext/tools/rgettext.rb', line 70

def generate_pot_header # :nodoc:
  time = Time.now.strftime("%Y-%m-%d %H:%M")
  off = Time.now.utc_offset
  sign = off <= 0 ? '-' : '+'
  time += sprintf('%s%02d%02d', sign, *(off.abs / 60).divmod(60))

  "# SOME DESCRIPTIVE TITLE.\n# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER\n# This file is distributed under the same license as the PACKAGE package.\n# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.\n#\n#, fuzzy\nmsgid \"\"\nmsgstr \"\"\n\"Project-Id-Version: PACKAGE VERSION\\\\n\"\n\"POT-Creation-Date: \#{time}\\\\n\"\n\"PO-Revision-Date: \#{time}\\\\n\"\n\"Last-Translator: FULL NAME <EMAIL@ADDRESS>\\\\n\"\n\"Language-Team: LANGUAGE <[email protected]>\\\\n\"\n\"MIME-Version: 1.0\\\\n\"\n\"Content-Type: text/plain; charset=UTF-8\\\\n\"\n\"Content-Transfer-Encoding: 8bit\\\\n\"\n\"Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\\\\n\"\n"
end

.parse(files) ⇒ Object

:nodoc:



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/gettext/tools/rgettext.rb', line 133

def parse(files) # :nodoc:
  ary = []
  files.each do |file|
    begin
      @ex_parsers.each do |klass|
        if klass.target?(file)
          ary = klass.parse(file, ary)
          break
        end
      end
    rescue
      puts "Error parsing " + file
      raise
    end
  end
  ary
end

.run(targetfiles = nil, out = STDOUT) ⇒ Object

:nodoc:



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/gettext/tools/rgettext.rb', line 194

def run(targetfiles = nil, out = STDOUT)  # :nodoc:
  if targetfiles.is_a? String
    targetfiles = [targetfiles]
  elsif ! targetfiles
    targetfiles, out = check_options
  end

  if targetfiles.size == 0
    raise ArgumentError, _("no input files")
  end

  if out.is_a? String
    File.open(File.expand_path(out), "w+") do |file|
      file.puts generate_pot_header
      file.puts generate_pot(parse(targetfiles))
    end
  else
    out.puts generate_pot_header
    out.puts generate_pot(parse(targetfiles))
  end
  self
end